import { FeatureBuilder } from './FeatureBuilder';
import { IGherkinParserConfig } from './lib/parseFeature';
import { IGherkinAst, IGherkinBackground, IGherkinMethods, IGherkinScenario, IHookFn } from './types';
export declare type IConfigureFn = (t: IGherkinMethods) => void;
export interface IDescribe {
    (name: string, fn: () => Promise<any> | any): void;
    skip: IDescribe;
    only: IDescribe;
}
export interface ITest {
    (name: string, fn: () => Promise<any> | any, timeout?: number): void;
    skip: ITest;
    only: ITest;
}
export interface ITestMethods {
    describe: IDescribe;
    test: ITest;
    beforeAll: IHookFn;
    afterAll: IHookFn;
}
export interface IGherkinTestParams extends IGherkinParserConfig {
    methods?: ITestMethods;
    defaultTimeout?: number;
}
/**
 * Create a gherkin test based on a feature file
 */
export declare function Feature(config: IGherkinTestParams | IGherkinTestParams['feature'], configure: IConfigureFn): {
    ast: IGherkinAst;
    featureBuilder: FeatureBuilder;
};
export declare const GherkinTest: typeof Feature;
export declare type IOnConfigured = (callback: () => void) => void;
export declare type ICategorizedSteps = (Pick<Required<IGherkinScenario>, 'Given' | 'When' | 'Then'> & {
    Background?: IGherkinBackground['Given'];
});
