"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * A gherkin feature file's table:
 *
 *   | a | b |
 *   | 1 | 2 |
 *
 * Becomes `IGherkinAstTableRows[]`
 *
 * @example
 *
 * const table = GherkinTableReader({ rows });
 * table.dict();
 */
function GherkinTableReader({ rows: inputRows = [] }) {
    const rowValues = inputRows
        .map(({ cells }) => cells.map(({ value }) => value));
    const getLeft = () => rowValues.map((cells) => cells[0]);
    const getTop = () => rowValues[0];
    const headers = (() => getTop());
    const dict = (() => {
        const keys = headers();
        const contentRows = rowValues.slice(1);
        return keys.reduce((o, key, index) => {
            return Object.assign({}, o, { [key]: contentRows.map((cells) => cells[index]) });
        }, {});
    });
    dict.left = (() => {
        const keys = rowValues.map((cells) => cells[0]);
        return rowValues.reduce((o, cells, index) => {
            /** The cells, after the left-most */
            const contentCells = cells.slice(1);
            return Object.assign({}, o, { [keys[index]]: contentCells });
        }, {});
    });
    dict.matrix = (() => {
        const topKeys = getTop()
            .slice(1); // Skip blank
        const leftKeys = getLeft()
            .slice(1); // Skip blank
        const contentRows = rowValues
            .slice(1) // Skip top
            .map((cells) => cells.slice(1)); // Skip left
        return leftKeys.reduce((l, leftKey, leftIndex) => {
            const topMap = topKeys.reduce((t, topKey, topIndex) => {
                const cells = contentRows[leftIndex];
                return Object.assign({}, t, { [topKey]: cells[topIndex] });
            }, {});
            return Object.assign({}, l, { [leftKey]: topMap });
        }, {});
    });
    const rows = (() => rowValues);
    rows.mapByTop = (() => {
        const keys = getTop();
        const contentRows = rowValues.slice(1);
        return contentRows.map((cells) => {
            return keys.reduce((o, key, index) => {
                return Object.assign({}, o, { [key]: cells[index] });
            }, {});
        });
    });
    return { dict, headers, rows };
}
exports.GherkinTableReader = GherkinTableReader;
