"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const errorParser = require("error-stack-parser");
const Gherkin = require("gherkin");
const isValidPath = require("is-valid-path");
const upath_1 = require("upath");
const FeatureBuilder_1 = require("../FeatureBuilder");
const readInputFile_1 = require("./readInputFile");
/** Parses a feature file from a relative filePath */
function parseFeature({ feature, stackIndex = 1 }) {
    const text = (() => {
        // Is a feature file body
        if (!isValidPath(feature)) {
            return feature;
        }
        const filePath = upath_1.toUnix(feature);
        const testFilePath = (() => {
            if (upath_1.isAbsolute(feature)) {
                return;
            }
            const error = new Error();
            /** Increment stackIndex due to the nested IIFE's it's within */
            return errorParser.parse(error)[stackIndex + 2].fileName;
        })();
        return readInputFile_1.readInputFile({ filePath, testFilePath });
    })();
    const parser = new Gherkin.Parser();
    const ast = parser.parse(text);
    const featureBuilder = new FeatureBuilder_1.FeatureBuilder(ast);
    return { ast, text, featureBuilder };
}
exports.parseFeature = parseFeature;
