"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const ExpressionMatcher_1 = require("./ExpressionMatcher");
const GherkinTableReader_1 = require("./GherkinTableReader");
function parseGherkinParameters(stepOrExamples, match) {
    const text = stepOrExamples.type === 'Step'
        ? stepOrExamples.text
        : stepOrExamples.name;
    const matcher = ExpressionMatcher_1.ExpressionMatcher(match);
    const matches = matcher.match(text) || [];
    const simpleParams = matches.map((arg) => arg.getValue());
    const paramSource = stepOrExamples.type === 'Step'
        ? stepOrExamples.argument
        : stepOrExamples;
    const argumentParam = parseGherkinForParameter(paramSource);
    const params = argumentParam
        ? [...simpleParams, argumentParam]
        : simpleParams;
    return params;
}
exports.parseGherkinParameters = parseGherkinParameters;
function parseGherkinForParameter(arg) {
    if (!arg) {
        return;
    }
    if (arg.type === 'DataTable') {
        return GherkinTableReader_1.GherkinTableReader({ rows: arg.rows });
    }
    if (arg.type === 'Examples') {
        const rows = [
            arg.tableHeader,
            ...arg.tableBody || [],
        ];
        return GherkinTableReader_1.GherkinTableReader({ rows });
    }
    if (arg.type === 'DocString') {
        return arg.content;
    }
}
